@@ -100,6 +100,7 @@ G_DEFINE_AUTOPTR_CLEANUP_FUNC (XfcePanelPlugin, g_object_unref)
  * @screen_position_changed : See #XfcePanelPlugin::screen-position-changed for more information.
  * @size_changed :            See #XfcePanelPlugin::size-changed for more information.
  * @orientation_changed :     See #XfcePanelPlugin::orientation-changed for more information.
+ * @hidden_event :            See #XfcePanelPlugin::hidden-event for more information.
  * @free_data :               See #XfcePanelPlugin::free-data for more information.
  * @save :                    See #XfcePanelPlugin::save for more information.
  * @about :                   See #XfcePanelPlugin::about for more information.
@@ -127,6 +128,8 @@ struct _XfcePanelPluginClass
                             gint size);
   void (*orientation_changed) (XfcePanelPlugin *plugin,
                                GtkOrientation orientation);
+  void (*hidden_event) (XfcePanelPlugin *plugin,
+                        gboolean hidden);
   void (*free_data) (XfcePanelPlugin *plugin);
   void (*save) (XfcePanelPlugin *plugin);
   void (*about) (XfcePanelPlugin *plugin);
@@ -144,7 +147,6 @@ struct _XfcePanelPluginClass
 
   /*< private >*/
   void (*reserved1) (void);
-  void (*reserved2) (void);
 };
 
 
